@@ -158,13 +158,23 @@ public class Config {
      */
     public boolean ENGINE_DEBUG = false;
 
-    /**
-     * internal switch for debugging
-     */
-    public int ENGINE_TEST_PERFORMANCE_RUN_COUNT = 1;
-
     /**
      * the logger to be used for logging
      */
     public org.slf4j.Logger logger = null;
+
+    /**
+     * the location of the performance directory
+     */
+    public String ENGINE_PERFORMANCEDIR = null;
+
+    /**
+     * the timeout in milliseconds, after which an entry is removed from the error cache
+     */
+    public long ENGINE_ERROR_CACHE_TIMEOUT_SECONDS = 0;
+
+    /**
+     * is cache lockup enabled for preview service
+     */
+    public boolean PREVIEW_ENABLE_CACHE_LOOKUP = false;
 }
