@@ -39,7 +39,7 @@ public interface IJobProcessor {
      * @param jobStatusListener The listener associated with the given server job
      * @return The unique id string of the added job or null in case of failure
      */
-    String addJob(IJob serverJob, JobPriority jobPriority, IJobStatusListener jobStatusListener);
+    String addJob(IJob serverJob, JobPriority jobPriority, IJobStatusListener jobStatusListener, String jobDescription);
 
     /**
      * Removes the Job with the given id from the queue of Jobs
