@@ -49,6 +49,7 @@
 
 package com.openexchange.documentconverter;
 
+
 /**
  * {@link Properties}
  *
@@ -116,8 +117,12 @@ public class Properties {
 
     static final public String PROP_FEATURES_ID = "FeaturesId"; // Integer
 
+    static final public String PROP_PERFID = "PerfId"; // String
+
     static final public String PROP_CONVERTER_COOKIE = "ConverterCookie"; // String
 
+    static final public String PROP_CACHE_ONLY = "CacheOnly"; // Boolean
+
     // -------------------------------------------------------------------------
 
     static final public String PROP_RESULT_CACHE_HASH = PROP_CACHE_HASH; // String
@@ -148,12 +153,18 @@ public class Properties {
 
     static final public String PROP_RESULT_TEMP_INPUT_FILE = "TempInputFile"; // File
 
+    static final public String PROP_RESULT_TEMP_INFO_FILENAME = PROP_INFO_FILENAME; // String
+
+    static final public String PROP_RESULT_TEMP_INPUT_TYPE = PROP_INPUT_TYPE; // String
+
     static final public String PROP_RESULT_SINGLE_PAGE_JOBTYPE = "SinglePageJobType"; // String
 
     static final public String PROP_RESULT_ZIP_ARCHIVE = PROP_ZIP_ARCHIVE; // Boolean
 
     static final public String PROP_RESULT_CACHE_REMOTEURL = "CacheRemoteUrl"; // String
 
+    static final public String PROP_RESULT_PERFID = PROP_PERFID; // String
+
     static final public String PROP_RESULT_CONVERTER_COOKIE = PROP_CONVERTER_COOKIE; // String
 
     // -------------------------------------------------------------------------
